@@ -61,7 +61,11 @@ class portfolios(quantim):
             raise ValueError("Both country and funds cannot be None")
         data = {'country':country, "funds":funds, "per":per, "range_in_months":range_in_months, 'total_rets_per':total_rets_per, 'ref_date':ref_date}
         resp = self.api_call('port_metrics', method="post", data=data, verify=False)
-        absolute_risk, relative_risk, real_rets, series = pd.DataFrame(resp['absolute_risk']), pd.DataFrame(resp['relative_risk']), pd.DataFrame(resp['real_rets']), pd.DataFrame(resp['series'])
+        absolute_risk, relative_risk, real_rets = pd.DataFrame(resp['absolute_risk']), pd.DataFrame(resp['relative_risk']), pd.DataFrame(resp['real_rets'])
+
+        series_df = pd.DataFrame(None)
+        for k in resp['series'].keys():
+            series_df = pd.concat([series_df, pd.DataFrame(resp['series'][k]).set_index('date')], axis=1)
         return absolute_risk, relative_risk, real_rets, series
 
     def attribution(self, port_name, ref_curr, bench_name=None, port_to_index=True, per='monthly', ini_date=None, rebal_dates_db=False, rebal_period='quarterly', sync_rebal_dates=False, reset_weights=True, backtest_assets=None, vol_model={"name":"ewma", "alpha":0.01}, delta_w=0.01, quant=0.95, var_normal=True, counter_assets=None):
