@@ -121,8 +121,13 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
 
 
     Portafolio['TIPO CALIFICACION'] = np.where(((Portafolio['CALIFICACION NUMERICA_x'].notnull()) & (Portafolio['TIPO CALIFICACION']=="Internacional")),"Local", Portafolio['TIPO CALIFICACION'])
-    Portafolio['CALIFICACION NUMERICA_x'] = np.where(Portafolio['CALIFICACION NUMERICA_x'].isnull(),Portafolio['CALIFICACION NUMERICA_y'],Portafolio['CALIFICACION NUMERICA_x'])
-
+    # QUITAR ESTE PASO y LEER CALIFICACIONES 6 [CALIFICACION EQUIV	CALIFICACION NUMERICA
+    # Portafolio['CALIFICACION NUMERICA_x'] = np.where(Portafolio['CALIFICACION NUMERICA_x'].isnull(),Portafolio['CALIFICACION NUMERICA_y'],Portafolio['CALIFICACION NUMERICA_x'])
+   
+    Calificaciones6=Calificaciones.loc[:,["CALIFICACION EQUIV", "CALIFICACION NUMERICA"]].drop_duplicates()
+    Calificaciones6.rename(columns={'CALIFICACION NUMERICA':'CALIFICACION NUMERICA FINAL'}, inplace=True)
+    Portafolio=pd.merge(Portafolio, Calificaciones6, how="left", left_on='CALIFICACION EQUIV', right_on='CALIFICACION EQUIV')
+    Portafolio['CALIFICACION NUMERICA_x'] = Portafolio['CALIFICACION NUMERICA FINAL']
 
     Portafolio['CLASE DE ACCIONES'] = np.where(Portafolio['CLASE DE ACCIONES']=="1","ORD",Portafolio['CLASE DE ACCIONES'])
     Portafolio['CLASE DE ACCIONES'] = np.where(Portafolio['CLASE DE ACCIONES']=="2","PREF",Portafolio['CLASE DE ACCIONES'])
